==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/ConditionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Conditions in alert instance to be matched for a given action rule. Default value is all. Multiple values could be provided with comma separation.
 * @property alertContext filter alerts by alert context (payload)
 * @property alertRuleId filter alerts by alert rule id
 * @property alertRuleName filter alerts by alert rule name
 * @property description filter alerts by alert rule description
 * @property monitorCondition filter alerts by monitor condition
 * @property monitorService filter alerts by monitor service
 * @property severity filter alerts by severity
 * @property targetResourceType filter alerts by target resource type
 */
public data class ConditionsArgs(
    public val alertContext: Output<ConditionArgs>? = null,
    public val alertRuleId: Output<ConditionArgs>? = null,
    public val alertRuleName: Output<ConditionArgs>? = null,
    public val description: Output<ConditionArgs>? = null,
    public val monitorCondition: Output<ConditionArgs>? = null,
    public val monitorService: Output<ConditionArgs>? = null,
    public val severity: Output<ConditionArgs>? = null,
    public val targetResourceType: Output<ConditionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs.builder()
            .alertContext(alertContext?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .alertRuleId(alertRuleId?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .alertRuleName(alertRuleName?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .description(description?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monitorCondition(monitorCondition?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monitorService(monitorService?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .severity(severity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .targetResourceType(
                targetResourceType?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ConditionsArgs].
 */
@PulumiTagMarker
public class ConditionsArgsBuilder internal constructor() {
    private var alertContext: Output<ConditionArgs>? = null

    private var alertRuleId: Output<ConditionArgs>? = null

    private var alertRuleName: Output<ConditionArgs>? = null

    private var description: Output<ConditionArgs>? = null

    private var monitorCondition: Output<ConditionArgs>? = null

    private var monitorService: Output<ConditionArgs>? = null

    private var severity: Output<ConditionArgs>? = null

    private var targetResourceType: Output<ConditionArgs>? = null

    /**
     * @param value filter alerts by alert context (payload)
     */
    @JvmName("opocllvhmgonjswl")
    public suspend fun alertContext(`value`: Output<ConditionArgs>) {
        this.alertContext = value
    }

    /**
     * @param value filter alerts by alert rule id
     */
    @JvmName("ijrrubiimwiemywo")
    public suspend fun alertRuleId(`value`: Output<ConditionArgs>) {
        this.alertRuleId = value
    }

    /**
     * @param value filter alerts by alert rule name
     */
    @JvmName("vepscsovdpkamhei")
    public suspend fun alertRuleName(`value`: Output<ConditionArgs>) {
        this.alertRuleName = value
    }

    /**
     * @param value filter alerts by alert rule description
     */
    @JvmName("mjerhkpfnkyogjud")
    public suspend fun description(`value`: Output<ConditionArgs>) {
        this.description = value
    }

    /**
     * @param value filter alerts by monitor condition
     */
    @JvmName("uixvxkajlykstymx")
    public suspend fun monitorCondition(`value`: Output<ConditionArgs>) {
        this.monitorCondition = value
    }

    /**
     * @param value filter alerts by monitor service
     */
    @JvmName("cgilhknyhahlyjvg")
    public suspend fun monitorService(`value`: Output<ConditionArgs>) {
        this.monitorService = value
    }

    /**
     * @param value filter alerts by severity
     */
    @JvmName("udkdvgqbdnqqkwed")
    public suspend fun severity(`value`: Output<ConditionArgs>) {
        this.severity = value
    }

    /**
     * @param value filter alerts by target resource type
     */
    @JvmName("sheggkcyrqfbvjhj")
    public suspend fun targetResourceType(`value`: Output<ConditionArgs>) {
        this.targetResourceType = value
    }

    /**
     * @param value filter alerts by alert context (payload)
     */
    @JvmName("bpnxojndakgbiikw")
    public suspend fun alertContext(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertContext = mapped
    }

    /**
     * @param argument filter alerts by alert context (payload)
     */
    @JvmName("dxfjhgduwydhdojj")
    public suspend fun alertContext(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertContext = mapped
    }

    /**
     * @param value filter alerts by alert rule id
     */
    @JvmName("mdxxpehusgttexcx")
    public suspend fun alertRuleId(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertRuleId = mapped
    }

    /**
     * @param argument filter alerts by alert rule id
     */
    @JvmName("faxxhjobgbmwhkne")
    public suspend fun alertRuleId(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertRuleId = mapped
    }

    /**
     * @param value filter alerts by alert rule name
     */
    @JvmName("xsifbmifhtcrfyec")
    public suspend fun alertRuleName(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertRuleName = mapped
    }

    /**
     * @param argument filter alerts by alert rule name
     */
    @JvmName("gwnllkrbilddbhmb")
    public suspend fun alertRuleName(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertRuleName = mapped
    }

    /**
     * @param value filter alerts by alert rule description
     */
    @JvmName("cpurebrugoxfatmg")
    public suspend fun description(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param argument filter alerts by alert rule description
     */
    @JvmName("uqoskbbbxalklxek")
    public suspend fun description(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.description = mapped
    }

    /**
     * @param value filter alerts by monitor condition
     */
    @JvmName("qfiryqqflwwvkdxc")
    public suspend fun monitorCondition(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitorCondition = mapped
    }

    /**
     * @param argument filter alerts by monitor condition
     */
    @JvmName("btmencffeltbkxno")
    public suspend fun monitorCondition(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monitorCondition = mapped
    }

    /**
     * @param value filter alerts by monitor service
     */
    @JvmName("fkjpboreughyitue")
    public suspend fun monitorService(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitorService = mapped
    }

    /**
     * @param argument filter alerts by monitor service
     */
    @JvmName("aadjrypdmfjtugrk")
    public suspend fun monitorService(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monitorService = mapped
    }

    /**
     * @param value filter alerts by severity
     */
    @JvmName("uwpnqhxbhvrgbafq")
    public suspend fun severity(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.severity = mapped
    }

    /**
     * @param argument filter alerts by severity
     */
    @JvmName("utjfdpxnktqexope")
    public suspend fun severity(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.severity = mapped
    }

    /**
     * @param value filter alerts by target resource type
     */
    @JvmName("unjpcwtixttdspjw")
    public suspend fun targetResourceType(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetResourceType = mapped
    }

    /**
     * @param argument filter alerts by target resource type
     */
    @JvmName("hsfepxahwuphgsmc")
    public suspend fun targetResourceType(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.targetResourceType = mapped
    }

    internal fun build(): ConditionsArgs = ConditionsArgs(
        alertContext = alertContext,
        alertRuleId = alertRuleId,
        alertRuleName = alertRuleName,
        description = description,
        monitorCondition = monitorCondition,
        monitorService = monitorService,
        severity = severity,
        targetResourceType = targetResourceType,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/ConditionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Conditions in alert instance to be matched for a given action rule. Default value is all. Multiple values could be provided with comma separation.
 * @property alertContext filter alerts by alert context (payload)
 * @property alertRuleId filter alerts by alert rule id
 * @property alertRuleName filter alerts by alert rule name
 * @property description filter alerts by alert rule description
 * @property monitorCondition filter alerts by monitor condition
 * @property monitorService filter alerts by monitor service
 * @property severity filter alerts by severity
 * @property targetResourceType filter alerts by target resource type
 */
public data class ConditionsArgs(
    public val alertContext: Output<ConditionArgs>? = null,
    public val alertRuleId: Output<ConditionArgs>? = null,
    public val alertRuleName: Output<ConditionArgs>? = null,
    public val description: Output<ConditionArgs>? = null,
    public val monitorCondition: Output<ConditionArgs>? = null,
    public val monitorService: Output<ConditionArgs>? = null,
    public val severity: Output<ConditionArgs>? = null,
    public val targetResourceType: Output<ConditionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.ConditionsArgs.builder()
            .alertContext(alertContext?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .alertRuleId(alertRuleId?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .alertRuleName(alertRuleName?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .description(description?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monitorCondition(monitorCondition?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monitorService(monitorService?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .severity(severity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .targetResourceType(
                targetResourceType?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ConditionsArgs].
 */
@PulumiTagMarker
public class ConditionsArgsBuilder internal constructor() {
    private var alertContext: Output<ConditionArgs>? = null

    private var alertRuleId: Output<ConditionArgs>? = null

    private var alertRuleName: Output<ConditionArgs>? = null

    private var description: Output<ConditionArgs>? = null

    private var monitorCondition: Output<ConditionArgs>? = null

    private var monitorService: Output<ConditionArgs>? = null

    private var severity: Output<ConditionArgs>? = null

    private var targetResourceType: Output<ConditionArgs>? = null

    /**
     * @param value filter alerts by alert context (payload)
     */
    @JvmName("ehfwtomrfsrvxucg")
    public suspend fun alertContext(`value`: Output<ConditionArgs>) {
        this.alertContext = value
    }

    /**
     * @param value filter alerts by alert rule id
     */
    @JvmName("qgvkgvotdaargjpx")
    public suspend fun alertRuleId(`value`: Output<ConditionArgs>) {
        this.alertRuleId = value
    }

    /**
     * @param value filter alerts by alert rule name
     */
    @JvmName("irrifwdavmrotcpc")
    public suspend fun alertRuleName(`value`: Output<ConditionArgs>) {
        this.alertRuleName = value
    }

    /**
     * @param value filter alerts by alert rule description
     */
    @JvmName("jnrtbvaxleqeblpy")
    public suspend fun description(`value`: Output<ConditionArgs>) {
        this.description = value
    }

    /**
     * @param value filter alerts by monitor condition
     */
    @JvmName("kqoimrteussmrvay")
    public suspend fun monitorCondition(`value`: Output<ConditionArgs>) {
        this.monitorCondition = value
    }

    /**
     * @param value filter alerts by monitor service
     */
    @JvmName("mmmlthwtisygwcew")
    public suspend fun monitorService(`value`: Output<ConditionArgs>) {
        this.monitorService = value
    }

    /**
     * @param value filter alerts by severity
     */
    @JvmName("aplogtipimqpomaq")
    public suspend fun severity(`value`: Output<ConditionArgs>) {
        this.severity = value
    }

    /**
     * @param value filter alerts by target resource type
     */
    @JvmName("ehpdnltpqglvulva")
    public suspend fun targetResourceType(`value`: Output<ConditionArgs>) {
        this.targetResourceType = value
    }

    /**
     * @param value filter alerts by alert context (payload)
     */
    @JvmName("imygtyenroffvmau")
    public suspend fun alertContext(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertContext = mapped
    }

    /**
     * @param argument filter alerts by alert context (payload)
     */
    @JvmName("ckvlkigusivvpiaq")
    public suspend fun alertContext(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertContext = mapped
    }

    /**
     * @param value filter alerts by alert rule id
     */
    @JvmName("toyognxjupifuefp")
    public suspend fun alertRuleId(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertRuleId = mapped
    }

    /**
     * @param argument filter alerts by alert rule id
     */
    @JvmName("yequrdulcgicrrrm")
    public suspend fun alertRuleId(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertRuleId = mapped
    }

    /**
     * @param value filter alerts by alert rule name
     */
    @JvmName("djclaxgcajrgaxoi")
    public suspend fun alertRuleName(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alertRuleName = mapped
    }

    /**
     * @param argument filter alerts by alert rule name
     */
    @JvmName("wlqhtoxhfbvrnxjn")
    public suspend fun alertRuleName(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.alertRuleName = mapped
    }

    /**
     * @param value filter alerts by alert rule description
     */
    @JvmName("nkajbodcnstfunwj")
    public suspend fun description(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param argument filter alerts by alert rule description
     */
    @JvmName("smspxhmxlhrffllq")
    public suspend fun description(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.description = mapped
    }

    /**
     * @param value filter alerts by monitor condition
     */
    @JvmName("ktbieykhnbhsdeea")
    public suspend fun monitorCondition(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitorCondition = mapped
    }

    /**
     * @param argument filter alerts by monitor condition
     */
    @JvmName("rpgqgkxkntsljnxo")
    public suspend fun monitorCondition(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monitorCondition = mapped
    }

    /**
     * @param value filter alerts by monitor service
     */
    @JvmName("gdsxwokyluxlpdrc")
    public suspend fun monitorService(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitorService = mapped
    }

    /**
     * @param argument filter alerts by monitor service
     */
    @JvmName("ufgtgpyrwneagsgh")
    public suspend fun monitorService(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monitorService = mapped
    }

    /**
     * @param value filter alerts by severity
     */
    @JvmName("cxgegrflhogfcwyx")
    public suspend fun severity(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.severity = mapped
    }

    /**
     * @param argument filter alerts by severity
     */
    @JvmName("jfstmmcbmmvrypvv")
    public suspend fun severity(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.severity = mapped
    }

    /**
     * @param value filter alerts by target resource type
     */
    @JvmName("ctavlayghavkchgm")
    public suspend fun targetResourceType(`value`: ConditionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetResourceType = mapped
    }

    /**
     * @param argument filter alerts by target resource type
     */
    @JvmName("pbgofrfgjqbmqcyb")
    public suspend fun targetResourceType(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = ConditionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.targetResourceType = mapped
    }

    internal fun build(): ConditionsArgs = ConditionsArgs(
        alertContext = alertContext,
        alertRuleId = alertRuleId,
        alertRuleName = alertRuleName,
        description = description,
        monitorCondition = monitorCondition,
        monitorService = monitorService,
        severity = severity,
        targetResourceType = targetResourceType,
    )
}
